Trait xml_dom::level2::CharacterData [−][src]
This corresponds to the DOM CharacterData interface.
Specification
The CharacterData interface extends Node with a set of attributes and
methods for accessing character data in the DOM. For clarity this set is defined here rather
than on each object that uses these attributes and methods. No DOM objects correspond directly
to CharacterData, though Text and others do inherit the interface from it.
All offsets in this interface start from 0.
As explained in the DOMString interface, text strings in the DOM are represented in UTF-16,
i.e. as a sequence of 16-bit units. In the following, the term 16-bit units is used whenever
necessary to indicate that indexing on CharacterData is done in 16-bit units.
Required methods
fn substring_data(&self, offset: usize, count: usize) -> Result<String>[src]
Extracts a range of data from the node.
Specification
Parameters
offsetof typeunsigned long: Start offset of substring to extract.countof typeunsigned long: The number of 16-bit units to extract.
Return Value
DOMString: The specified substring. If the sum ofoffsetandcountexceeds thelength, then all 16-bit units to the end of the data are returned.
Exceptions
INDEX_SIZE_ERR: Raised if the specifiedoffsetis negative or greater than the number of 16-bit units in data, or if the specifiedcountis negative.DOMSTRING_SIZE_ERR: Raised if the specified range of text does not fit into aDOMString.
fn append_data(&mut self, data: &str) -> Result<()>[src]
Append the string to the end of the character data of the node.
Specification
Upon success, data provides access to the concatenation of data and the DOMString specified.
Parameters
argof typeDOMString: The DOMString to append.
Exceptions
NO_MODIFICATION_ALLOWED_ERR: Raised if this node is readonly.
fn insert_data(&mut self, offset: usize, data: &str) -> Result<()>[src]
Insert a string at the specified 16-bit unit offset.
Specification
Parameters
offsetof typeunsigned long: The character offset at which to insert.argof typeDOMString: The DOMString to insert.
Exceptions
INDEX_SIZE_ERR: Raised if the specifiedoffsetis negative or greater than the number of 16-bit units in data.NO_MODIFICATION_ALLOWED_ERR: Raised if this node is readonly.
fn delete_data(&mut self, offset: usize, count: usize) -> Result<()>[src]
Remove a range of 16-bit units from the node. Upon success, data and length reflect the change.
Specification
Parameters
offsetof typeunsigned long: The offset from which to start removing.countof typeunsigned long: The number of 16-bit units to delete. If the sum ofoffsetandcountexceedslengththen all 16-bit units from offset to the end of the data are deleted.
Exceptions
INDEX_SIZE_ERR: Raised if the specifiedoffsetis negative or greater than the number of 16-bit units in data, or if the specifiedcountis negative.NO_MODIFICATION_ALLOWED_ERR: Raised if this node is readonly.
fn replace_data(
&mut self,
offset: usize,
count: usize,
data: &str
) -> Result<()>[src]
&mut self,
offset: usize,
count: usize,
data: &str
) -> Result<()>
Replace the characters starting at the specified 16-bit unit offset with the specified string.
Specification
Parameters
offsetof typeunsigned long: The offset from which to start replacing.countof typeunsigned long: The number of 16-bit units to replace. If the sum ofoffsetandcountexceedslength, then all 16-bit units to the end of the data are replaced; (i.e., the effect is the same as a remove method call with the same range, followed by an append method invocation).argof typeDOMString: TheDOMStringwith which the range must be replaced. Exceptions
INDEX_SIZE_ERR: Raised if the specified offset is negative or greater than the number
of 16-bit units in data, or if the specified count is negative.
NO_MODIFICATION_ALLOWED_ERR: Raised if this node is readonly.
Provided methods
fn length(&self) -> usize[src]
The number of 16-bit units that are available through data and the substringData method
below. This may have the value zero, i.e., CharacterData nodes may be empty.
Note: This implementation drops the _data suffix from the methods for clarity.
fn data(&self) -> Option<String>[src]
The character data of the node that implements this interface.
Specification
The DOM implementation may not put arbitrary limits on the amount of data that may be
stored in a CharacterData node. However, implementation limits may mean that the entirety
of a node’s data may not fit into a single DOMString. In such cases, the user may call
substringData to retrieve the data in appropriately sized pieces.
Exceptions on setting
NO_MODIFICATION_ALLOWED_ERR: Raised when the node is readonly.
Exceptions on retrieval
DOMSTRING_SIZE_ERR: Raised when it would return more characters than fit in aDOMStringvariable on the implementation platform.
fn set_data(&mut self, data: &str) -> Result<()>[src]
Set the data for the node; see data().
fn unset_data(&mut self) -> Result<()>[src]
Set the data for the node to None; see data().
Implementors
impl CharacterData for RefNode[src]
fn substring_data(&self, offset: usize, count: usize) -> Result<String>[src]
fn append_data(&mut self, new_data: &str) -> Result<()>[src]
fn insert_data(&mut self, offset: usize, new_data: &str) -> Result<()>[src]
fn delete_data(&mut self, offset: usize, count: usize) -> Result<()>[src]
fn replace_data(
&mut self,
offset: usize,
count: usize,
replace_data: &str
) -> Result<()>[src]
&mut self,
offset: usize,
count: usize,
replace_data: &str
) -> Result<()>