pub trait Element: Node {
Show 16 methods
// Required methods
fn get_attribute(&self, name: &str) -> Option<String>;
fn set_attribute(&mut self, name: &str, value: &str) -> Result<()>;
fn remove_attribute(&mut self, _name: &str) -> Result<()>;
fn get_attribute_node(&self, name: &str) -> Option<Self::NodeRef>;
fn set_attribute_node(
&mut self,
new_attribute: Self::NodeRef,
) -> Result<Self::NodeRef>;
fn remove_attribute_node(
&mut self,
_old_attribute: Self::NodeRef,
) -> Result<Self::NodeRef>;
fn get_elements_by_tag_name(&self, _tag_name: &str) -> Vec<Self::NodeRef>;
fn get_attribute_ns(
&self,
_namespace_uri: &str,
_local_name: &str,
) -> Option<String>;
fn set_attribute_ns(
&mut self,
namespace_uri: &str,
qualified_name: &str,
value: &str,
) -> Result<()>;
fn remove_attribute_ns(
&mut self,
_namespace_uri: &str,
_local_name: &str,
) -> Result<()>;
fn get_attribute_node_ns(
&self,
_namespace_uri: &str,
_local_name: &str,
) -> Option<Self::NodeRef>;
fn set_attribute_node_ns(
&mut self,
_new_attribute: Self::NodeRef,
) -> Result<Self::NodeRef>;
fn get_elements_by_tag_name_ns(
&self,
_namespace_uri: &str,
_local_name: &str,
) -> Vec<Self::NodeRef>;
fn has_attribute(&self, name: &str) -> bool;
fn has_attribute_ns(&self, namespace_uri: &str, local_name: &str) -> bool;
// Provided method
fn tag_name(&self) -> String { ... }
}Expand description
This corresponds to the DOM Element interface.
Specification
The Element interface represents an element in an HTML or XML document. Elements may have
attributes associated with them; since the Element interface inherits from Node,
the generic Node interface attribute attributes may be used to retrieve the set of all
attributes for an element. There are methods on the Element interface to retrieve either an
Attr object by name or an attribute value by name. In XML, where an
attribute value may contain entity references, an Attr object should be retrieved to examine
the possibly fairly complex sub-tree representing the attribute value. On the other hand, in
HTML, where all attributes have simple string values, methods to directly access an attribute
value can safely be used as a convenience.
Note: In DOM Level 2, the method normalize is inherited from the Node interface where
it was moved.
Required Methods
Sourcefn get_attribute(&self, name: &str) -> Option<String>
fn get_attribute(&self, name: &str) -> Option<String>
Retrieves an attribute value by name.
Specification
Parameters
nameof typeDOMString: The name of the attribute to retrieve.
Return Value
DOMString: TheAttrvalue as a string, or the empty string if that attribute does not have a specified or default value.
Sourcefn set_attribute(&mut self, name: &str, value: &str) -> Result<()>
fn set_attribute(&mut self, name: &str, value: &str) -> Result<()>
Adds a new attribute.
Specification
If an attribute with that name is already present in the element, its value is changed to be that of the value parameter. This value is a simple string; it is not parsed as it is being set. So any markup (such as syntax to be recognized as an entity reference) is treated as literal text, and needs to be appropriately escaped by the implementation when it is written out. In order to assign an attribute value that contains entity references, the user must create an Attr node plus any Text and EntityReference nodes, build the appropriate subtree, and use setAttributeNode to assign it as the value of an attribute.
To set an attribute with a qualified name and namespace URI, use the setAttributeNS method.
Parameters
nameof typeDOMString: The name of the attribute to create or alter.valueof typeDOMString: Value to set in string form.
Exceptions
INVALID_CHARACTER_ERR: Raised if the specified name contains an illegal character.NO_MODIFICATION_ALLOWED_ERR: Raised if this node is readonly.
Sourcefn remove_attribute(&mut self, _name: &str) -> Result<()>
fn remove_attribute(&mut self, _name: &str) -> Result<()>
Removes an attribute by name. If the removed attribute is known to have a default value, an attribute immediately appears containing the default value as well as the corresponding namespace URI, local name, and prefix when applicable.
Specification
To remove an attribute by local name and namespace URI, use the removeAttributeNS method.
Parameters
nameof typeDOMString: The name of the attribute to remove.
Exceptions
NO_MODIFICATION_ALLOWED_ERR: Raised if this node is readonly.
Sourcefn get_attribute_node(&self, name: &str) -> Option<Self::NodeRef>
fn get_attribute_node(&self, name: &str) -> Option<Self::NodeRef>
Retrieves an attribute node by name.
Specification
To retrieve an attribute node by qualified name and namespace URI, use the
getAttributeNodeNS method.
Parameters
nameof typeDOMString: The name (nodeName) of the attribute to retrieve.
Return Value
Attr: TheAttrnode with the specified name (nodeName) or null if there is no such attribute.
Sourcefn set_attribute_node(
&mut self,
new_attribute: Self::NodeRef,
) -> Result<Self::NodeRef>
fn set_attribute_node( &mut self, new_attribute: Self::NodeRef, ) -> Result<Self::NodeRef>
Adds a new attribute node.
Specification
If an attribute with that name (nodeName) is already present in the element, it is
replaced by the new one.
To add a new attribute node with a qualified name and namespace URI, use the
setAttributeNodeNS method.
Parameters
newAttrof typeAttr: TheAttrnode to add to the attribute list.
Return Value
Attr: If thenewAttrattribute replaces an existing attribute, the replacedAttrnode is returned, otherwisenullis returned.
Exceptions
WRONG_DOCUMENT_ERR: Raised ifnewAttrwas created from a different document than the one that created the element.NO_MODIFICATION_ALLOWED_ERR: Raised if this node is readonly.INUSE_ATTRIBUTE_ERR: Raised ifnewAttris already an attribute of anotherElementobject. The DOM user must explicitly cloneAttrnodes to re-use them in other elements.
Sourcefn remove_attribute_node(
&mut self,
_old_attribute: Self::NodeRef,
) -> Result<Self::NodeRef>
fn remove_attribute_node( &mut self, _old_attribute: Self::NodeRef, ) -> Result<Self::NodeRef>
Removes the specified attribute node.
Specification
If the removed Attr has a default value it is immediately replaced. The replacing
attribute has the same namespace URI and local name, as well as the original prefix, when
applicable.
Parameters
oldAttrof typeAttr: TheAttrnode to remove from the attribute list.
Return Value
Attr: TheAttrnode that was removed.
Exceptions
NO_MODIFICATION_ALLOWED_ERR: Raised if this node is readonly.NOT_FOUND_ERR: Raised if oldAttr is not an attribute of the element.
Sourcefn get_elements_by_tag_name(&self, _tag_name: &str) -> Vec<Self::NodeRef>
fn get_elements_by_tag_name(&self, _tag_name: &str) -> Vec<Self::NodeRef>
Returns a NodeList of all descendant Elements with a given tag name, in the order in
which they are encountered in a preorder traversal of this Element tree.
Specification
Parameters
nameof typeDOMString: The name of the tag to match on. The special value “*” matches all tags.
Return Value
NodeList: A list of matchingElementnodes.
Sourcefn get_attribute_ns(
&self,
_namespace_uri: &str,
_local_name: &str,
) -> Option<String>
fn get_attribute_ns( &self, _namespace_uri: &str, _local_name: &str, ) -> Option<String>
Retrieves an attribute value by local name and namespace URI.
Specification
HTML-only DOM implementations do not need to implement this method.
Parameters
namespaceURIof typeDOMString: The namespace URI of the attribute to retrieve.localNameof typeDOMString: The local name of the attribute to retrieve.
Return Value
DOMString: TheAttrvalue as a string, or the empty string if that attribute does not have a specified or default value.
Sourcefn set_attribute_ns(
&mut self,
namespace_uri: &str,
qualified_name: &str,
value: &str,
) -> Result<()>
fn set_attribute_ns( &mut self, namespace_uri: &str, qualified_name: &str, value: &str, ) -> Result<()>
Adds a new attribute.
Specification
If an attribute with the same local name and namespace URI is already present on the
element, its prefix is changed to be the prefix part of the qualifiedName, and its
value is changed to be the value parameter. This value is a simple string; it is not
parsed as it is being set. So any markup (such as syntax to be recognized as an entity
reference) is treated as literal text, and needs to be appropriately escaped by the
implementation when it is written out. In order to assign an attribute value that contains
entity references, the user must create an Attr node plus any Text and EntityReference
nodes, build the appropriate subtree, and use setAttributeNodeNS or setAttributeNode
to assign it as the value of an attribute.
HTML-only DOM implementations do not need to implement this method.
Parameters
namespaceURIof typeDOMString: The namespace URI of the attribute to create or alter.qualifiedNameof typeDOMString: The qualified name of the attribute to create or alter.valueof typeDOMString: The value to set in string form.
Exceptions
INVALID_CHARACTER_ERR: Raised if the specified qualified name contains an illegal character.NO_MODIFICATION_ALLOWED_ERR: Raised if this node is readonly.NAMESPACE_ERR: Raised if thequalifiedNameis malformed, if thequalifiedNamehas a prefix and thenamespaceURIis null, if thequalifiedNamehas a prefix that is “xml” and thenamespaceURIis different from ‘http://www.w3.org/XML/1998/namespace’, or if thequalifiedNameis “xmlns” and thenamespaceURIis different from<http://www.w3.org/2000/xmlns/>.
Sourcefn remove_attribute_ns(
&mut self,
_namespace_uri: &str,
_local_name: &str,
) -> Result<()>
fn remove_attribute_ns( &mut self, _namespace_uri: &str, _local_name: &str, ) -> Result<()>
Removes an attribute by local name and namespace URI.
Specification
If the removed attribute has a default value it is immediately replaced. The replacing attribute has the same namespace URI and local name, as well as the original prefix.
HTML-only DOM implementations do not need to implement this method.
Parameters
namespaceURIof typeDOMString: The namespace URI of the attribute to remove.localNameof typeDOMString: The local name of the attribute to remove.
Exceptions
NO_MODIFICATION_ALLOWED_ERR: Raised if this node is readonly.
Sourcefn get_attribute_node_ns(
&self,
_namespace_uri: &str,
_local_name: &str,
) -> Option<Self::NodeRef>
fn get_attribute_node_ns( &self, _namespace_uri: &str, _local_name: &str, ) -> Option<Self::NodeRef>
Retrieves an Attr node by local name and namespace URI.
Specification
HTML-only DOM implementations do not need to implement this method.
Parameters
namespaceURIof typeDOMString: The namespace URI of the attribute to retrieve.localNameof typeDOMString: The local name of the attribute to retrieve.
Return Value
Attr: TheAttrnode with the specified attribute local name and namespace URI ornullif there is no such attribute.
Sourcefn set_attribute_node_ns(
&mut self,
_new_attribute: Self::NodeRef,
) -> Result<Self::NodeRef>
fn set_attribute_node_ns( &mut self, _new_attribute: Self::NodeRef, ) -> Result<Self::NodeRef>
Adds a new attribute.
Specification
If an attribute with that local name and that namespace URI is already present in the element, it is replaced by the new one.
HTML-only DOM implementations do not need to implement this method.
Parameters
newAttrof typeAttr: TheAttrnode to add to the attribute list.
Return Value
Attr: If thenewAttrattribute replaces an existing attribute with the same local name and namespace URI, the replacedAttrnode is returned, otherwisenullis returned.
Exceptions
WRONG_DOCUMENT_ERR: Raised if newAttr was created from a different document than the one that created the element.NO_MODIFICATION_ALLOWED_ERR: Raised if this node is readonly.INUSE_ATTRIBUTE_ERR: Raised ifnewAttris already an attribute of anotherElementobject. The DOM user must explicitly cloneAttrnodes to re-use them in other elements.
Sourcefn get_elements_by_tag_name_ns(
&self,
_namespace_uri: &str,
_local_name: &str,
) -> Vec<Self::NodeRef>
fn get_elements_by_tag_name_ns( &self, _namespace_uri: &str, _local_name: &str, ) -> Vec<Self::NodeRef>
Returns a NodeList of all the descendant Elements with a given local name and namespace
URI in the order in which they are encountered in a preorder traversal of this Element tree.
Specification
HTML-only DOM implementations do not need to implement this method.
Parameters
namespaceURIof typeDOMString: The namespace URI of the elements to match on. The special value “*” matches all namespaces.localNameof typeDOMString: The local name of the elements to match on. The special value “*” matches all local names.
Return Value
NodeList: A newNodeListobject containing all the matchedElements.
Sourcefn has_attribute(&self, name: &str) -> bool
fn has_attribute(&self, name: &str) -> bool
Returns true when an attribute with a given name is specified on this element or has a default
value, false otherwise.
Specification
Parameters
nameof typeDOMString: The name of the attribute to look for.
Return Value
boolean:trueif an attribute with the given name is specified on this element or has a default value,falseotherwise.
Sourcefn has_attribute_ns(&self, namespace_uri: &str, local_name: &str) -> bool
fn has_attribute_ns(&self, namespace_uri: &str, local_name: &str) -> bool
Returns true when an attribute with a given local name and namespace URI is specified on
this element or has a default value, false otherwise.
Specification
HTML-only DOM implementations do not need to implement this method.
Parameters
namespaceURIof typeDOMString: The namespace URI of the attribute to look for.localNameof typeDOMString: The local name of the attribute to look for.
Return Value
boolean:trueif an attribute with the given local name and namespace URI is specified or has a default value on this element,falseotherwise.
Provided Methods
Sourcefn tag_name(&self) -> String
fn tag_name(&self) -> String
The name of the element.
Specification
For example, in:
<elementExample id="demo">
...
</elementExample>tagName has the value “elementExample”. Note that this is case-preserving in XML, as
are all of the operations of the DOM. The HTML DOM returns the tagName of an HTML element
in the canonical uppercase form, regardless of the case in the source HTML document.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".